(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59664,       1548]*)
(*NotebookOutlinePosition[     65497,       1700]*)
(*  CellTagsIndexPosition[     64253,       1669]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Demo S-Decomposition.", "Title"],

Cell["Tudor Jebelean", "Subtitle"],

Cell["Mar. 2006", "Subsubtitle"],

Cell[CellGroupData[{

Cell["2. Initial Knowledge", "Section"],

Cell[CellGroupData[{

Cell["Auxiliary knowledge", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sum of functions\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\((f\[CirclePlus]g)\)[x])\) := \((f[x] + g[x])\)\), 
              "\"\<\[CirclePlus]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Definition (sum of functions)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<product of functions\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\((f\[CircleDot]g)\)[x])\) := \((f[x]*g[x])\)\), 
              "\"\<\[CirclePlus]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Definition (product of functions)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of sum\>\"", 
        ",", \(any[x, y, a, b, \[Delta], \[Epsilon]]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\[LeftBracketingBar]x - 
                          a\[RightBracketingBar] < \((\[Epsilon]/
                          2)\) \[And] \[LeftBracketingBar]y - 
                          b\[RightBracketingBar] < \((\[Epsilon]/
                          2)\))\)\[DoubleLongRightArrow]\((\
\[LeftBracketingBar]\((x + y)\) - \((a + 
                            b)\)\[RightBracketingBar] < \[Epsilon])\)\), 
              "\"\<\[LeftBracketingBar]++\[RightBracketingBar]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (distance of sum)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of product\>\"", 
        ",", \(any[x, y, a, b, \[Delta], \[Epsilon]]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\[LeftBracketingBar]x - 
                          a\[RightBracketingBar] < \((\[Epsilon]/\((1 + \
\[LeftBracketingBar]a\[RightBracketingBar] + \[LeftBracketingBar]b\
\[RightBracketingBar])\))\) \[And] \[LeftBracketingBar]y - 
                          b\[RightBracketingBar] < \((\[Epsilon]/\((1 + \
\[LeftBracketingBar]a\[RightBracketingBar] + \[LeftBracketingBar]b\
\[RightBracketingBar])\))\))\)\[DoubleLongRightArrow]\((\[LeftBracketingBar]\(\
(x*y)\) - \((a*b)\)\[RightBracketingBar] < \[Epsilon])\)\), 
              "\"\<\[LeftBracketingBar]**\[RightBracketingBar]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (distance of product)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<max\>\"", ",", \(any[k, i, j]\), ",", "\n", "\t", GridBox[{
            {\(\((k \[GreaterEqual] 
                    max[i, j])\)\[DoubleLongRightArrow]\((k \[GreaterEqual] 
                      i \[And] k \[GreaterEqual] j)\)\), "\"\<max:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (max)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<min\>\"", ",", \(any[k, i, j]\), ",", "\n", "\t", GridBox[{
            {\(\((k < min[i, j])\)\[DoubleLongLeftRightArrow]\((k < i \[And] 
                    k < j)\)\), "\"\<min:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (min)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<eps/2\>\"", ",", \(any[\[Epsilon]]\), ",", "\n", "\t", GridBox[{
            {\(\((\[Epsilon] > 
                    0)\)\[DoubleLongRightArrow]\((\((\[Epsilon]/2)\) > 
                    0)\)\), "\"\<e/2\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (eps/2)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<eps/ab\>\"", ",", \(any[\[Epsilon], a, b]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\[Epsilon] > 
                    0)\)\[DoubleLongRightArrow]\((\((\[Epsilon]/\((1 + \
\[LeftBracketingBar]a\[RightBracketingBar] + \[LeftBracketingBar]b\
\[RightBracketingBar])\))\) > 0)\)\), "\"\<e/ab\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (eps/ab)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<auxiliary\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<sum of functions\>"]\)},
            {\(Definition["\<product of functions\>"]\)},
            {\(Proposition["\<distance of sum\>"]\)},
            {\(Proposition["\<distance of product\>"]\)},
            {\(Proposition["\<max\>"]\)},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<min\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<eps/2\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<eps/ab\>\"", "]"}]}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Theory (auxiliary)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Goals", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<conv of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, g\)\((\((\((conv[f] \[And] 
                          conv[g])\)\n\t\[DoubleLongRightArrow]
                      conv[f\[CirclePlus]g])\))\)\), "\"\<c+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (conv of sum)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<conv of sum\>\"", ",", "\n", "\t", GridBox[{
            {\((\((\((conv[f\_1] \[And] 
                        conv[f\_2])\)\n\t\[DoubleLongRightArrow]
                    conv[f\_1\[CirclePlus]f\_2])\))\), "\"\<c+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (conv of sum)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<conv of product\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, g\)\((\((\((conv[f] \[And] 
                          conv[g])\)\n\t\[DoubleLongRightArrow]
                      conv[f\[CircleDot]g])\))\)\), "\"\<c*\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (conv of product)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<lim of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, g, a, b\)\((\((\((lim[f, a] \[And] 
                          lim[g, b])\)\n\t\[DoubleLongRightArrow]
                      lim[f\[CirclePlus]g, a + b])\))\)\), "\"\<l+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (lim of sum)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<lim of product\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, g, a, b\)\((\((\((lim[f, a] \[And] 
                          lim[g, b])\)\n\t\[DoubleLongRightArrow]
                      lim[f\[CircleDot]g, a*b])\))\)\), "\"\<l*\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (lim of product)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<cont of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\((cont[f\_1] \[And] cont[f\_2])\)\[DoubleLongRightArrow]
                cont[f\_1\[CirclePlus]f\_2]\), "\"\<c+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (cont of sum)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<cont of product\>\"", ",", "\n", "\t", GridBox[{
            {\(\((cont[f\_1] \[And] cont[f\_2])\)\[DoubleLongRightArrow]
                cont[f\_1\[CircleDot]f\_2]\), "\"\<c*\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (cont of product)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<unif-cont of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\((ucont[f\_1] \[And] ucont[f\_2])\)\[DoubleLongRightArrow]
                ucont[f\_1\[CirclePlus]f\_2]\), "\"\<c+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (unif-cont of sum)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<unif-cont of product\>\"", ",", "\n", "\t", GridBox[{
            {\(\((ucont[f\_1] \[And] ucont[f\_2])\)\[DoubleLongRightArrow]
                ucont[f\_1\[CircleDot]f\_2]\), "\"\<c*\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  CellTags->"Proposition (unif-cont of product)"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Convergence", "Section"],

Cell[CellGroupData[{

Cell["3.1. Incomplete knowledge base", "Subsection"],

Cell["\<\
We try the proof using only the definitions. As the proof fails, we add more \
knowledge (possibly inspired by the conjectures).\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<conv\>\"", ",", \(any[f]\), ",", "\n", "\t", GridBox[{
            {\(conv[
                  f]\  : \[NegativeMediumSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[Exists] \+a\(\[ForAll] \+\[Epsilon]\((\[Epsilon] \
> 0)\)\[DoubleLongRightArrow]\(\[Exists] \+N\(\(\(\ \)\(\[ForAll]\)\)\+n\) \
\((n \[GreaterEqual] N)\)\[DoubleLongRightArrow]\((\[LeftBracketingBar]f[n] - 
                                      a\[RightBracketingBar] < \
\[Epsilon])\)\)\)\)\)\), "\"\<c:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (conv)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<conv of sum\>"], 
        using \[Rule] {Definition["\<conv\>"], 
            Definition["\<sum of functions\>"]}\), "]"}], ";"}]], "Input",
  CellTags->"Lemma (Conjecture\[Dash]1)"],

Cell[BoxData[
    \("The prover generated Lemma[\"Conjecture\[Dash]1\"]"\)], "Print",
  CellTags->"Lemma (Conjecture\[Dash]10)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lemma["\<Conjecture\[Dash]1\>"]\)], "Input"],

Cell[BoxData[
    RowBox[{"\[Bullet]lma", "[", 
      RowBox[{"\<\"Conjecture\[Dash]1\"\>", ",", \(\[Bullet]range[]\), ",", 
        "True", ",", 
        RowBox[{"\[Bullet]flist", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\<\"Conjecture\[Dash]1\"\>", ",", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["a1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["a2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]], 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["a0",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], " "}]], 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["\[Epsilon]0",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["\[Epsilon]1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["\[Epsilon]2",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]], 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["n0",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], " "}]], 
                        RowBox[{
                          UnderscriptBox["\[Exists]", 
                            RowBox[{
                              StyleBox["n1",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], ",", 
                              StyleBox["n2",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]], 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                RowBox[{
                                  RowBox[{"\[LeftBracketingBar]", 
                                    RowBox[{
                                      RowBox[{\(f\_1\), "[", 
                                        StyleBox["n1",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "]"}], "-", 
                                      StyleBox["a1",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}], 
                                    "\[RightBracketingBar]"}], "<", 
                                  StyleBox["\[Epsilon]1",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}], "\[And]", 
                                RowBox[{
                                  RowBox[{"\[LeftBracketingBar]", 
                                    RowBox[{
                                      RowBox[{\(f\_2\), "[", 
                                        StyleBox["n2",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "]"}], "-", 
                                      StyleBox["a2",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]}], 
                                    "\[RightBracketingBar]"}], "<", 
                                  StyleBox["\[Epsilon]2",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}]}], "\[Implies]", 
                              RowBox[{
                                RowBox[{"\[LeftBracketingBar]", 
                                  RowBox[{
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{\(f\_1\), "[", 
                                        StyleBox["n0",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "]"}], "+", 
                                        RowBox[{\(f\_2\), "[", 
                                        StyleBox["n0",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "]"}]}], ")"}], 
                                    "-", 
                                    StyleBox["a0",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}], 
                                  "\[RightBracketingBar]"}], "<", 
                                StyleBox["\[Epsilon]0",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}]}]}]}]}]}]}], 
            "]"}], "]"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.1  .1\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-1-1.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<conv of sum\>"], 
        using \[Rule] {Definition["\<conv\>"], 
            Definition["\<sum of functions\>"], 
            Proposition["\<distance of sum\>"]}\), "]"}], ";"}]], "Input",
  CellTags->"Lemma (Conjecture\[Dash]2)"],

Cell[BoxData[
    \("The prover generated Lemma[\"Conjecture\[Dash]2\"]"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lemma["\<Conjecture\[Dash]2\>"]\)], "Input"],

Cell[BoxData[
    RowBox[{"\[Bullet]lma", "[", 
      RowBox[{"\<\"Conjecture\[Dash]2\"\>", ",", \(\[Bullet]range[]\), ",", 
        "True", ",", 
        RowBox[{"\[Bullet]flist", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\<\"Conjecture\[Dash]2\"\>", ",", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Trademark]N1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["\[Trademark]N2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]], 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Trademark]N0",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], " "}]], 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["n0",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["n0",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[GreaterEqual]", 
                          StyleBox["\[Trademark]N0",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "\[Implies]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["n0",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[GreaterEqual]", 
                            StyleBox["\[Trademark]N1",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "\[And]", 
                          RowBox[{
                            StyleBox["n0",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[GreaterEqual]", 
                            StyleBox["\[Trademark]N2",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}]}], ")"}]}]}]}]}], "]"}], 
          "]"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.1  .2\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-1-2.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<conv of sum\>"], 
        using \[Rule] {Definition["\<conv\>"], 
            Definition["\<sum of functions\>"], 
            Proposition["\<distance of sum\>"], Proposition["\<max\>"]}\), 
        "]"}], ";"}]], "Input",
  CellTags->"Lemma (Conjecture\[Dash]3)"],

Cell[BoxData[
    \("The prover generated Lemma[\"Conjecture\[Dash]3\"]"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lemma["\<Conjecture\[Dash]3\>"]\)], "Input"],

Cell[BoxData[
    RowBox[{"\[Bullet]lma", "[", 
      RowBox[{"\<\"Conjecture\[Dash]3\"\>", ",", \(\[Bullet]range[]\), ",", 
        "True", ",", 
        RowBox[{"\[Bullet]flist", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\<\"Conjecture\[Dash]3\"\>", ",", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]0",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["\[Epsilon]0",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ">", "0"}], "\[Implies]", 
                    RowBox[{
                      FractionBox[
                        StyleBox["\[Epsilon]0",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "2"], ">", "0"}]}], ")"}]}]}], 
            "]"}], "]"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.1  .3\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-1-3.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", 
        RowBox[{\(Proposition["\<conv of sum\>"]\), ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              
              RowBox[{\(Definition["\<conv\>"]\), 
                ",", \(Definition["\<sum of functions\>"]\), 
                ",", \(Proposition["\<distance of sum\>"]\), 
                ",", \(Proposition["\<max\>"]\), ",", 
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", "\"\<eps/2\>\"", "]"}]}], 
              "}"}]}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.1  .4\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-1-4.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.2. Complete knowledge base", "Subsection"],

Cell["\<\
The knowledge base contains all the assumptions which are necessary for both \
the sum and the product proofs. Note how the prover extracts from the \
knowledge base only those assumptions which are necessary for the current \
proof.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<conv of sum\>"], 
        using \[Rule] {Definition["\<conv\>"], Theory["\<auxiliary\>"]}\), 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.2  .1\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-2-1.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell["\<\
The proof can be transformed into \"presentation style\": the appropriate \
values for the meta-variables \"magically\" show-up ehen they are needed. \
Note that one has to evaluate the cell bellow imediately after the previous \
one, because the command takes as input the proof object produced there.\
\>", "Text"],

Cell[BoxData[
    \(Show[TransMeta[%]]\)], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.2  .1  a\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-2-1a.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<conv of product\>"], 
        using \[Rule] {Definition["\<conv\>"], Theory["\<auxiliary\>"]}\), 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.2  .2\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-2-2.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Show[TransMeta[%]]\)], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(3.2  .2  a\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p3-2-2a.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Continuity", "Section"],

Cell[CellGroupData[{

Cell["4.1. Simple definition", "Subsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<cont\>\"", ",", \(any[f]\), ",", "\n", "\t", GridBox[{
            {\(cont[
                  f]\  : \[NegativeMediumSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+x\(\[ForAll] \+\[Epsilon]\(\[Exists] \
\+\[Delta]\(\(\(\ \)\(\[ForAll]\)\)\+y\) \((\[LeftBracketingBar]y - 
                                    x\[RightBracketingBar] < \[Delta])\)\
\[DoubleLongRightArrow]\((\[LeftBracketingBar]f[y] - 
                                    f[x]\[RightBracketingBar] < \[Epsilon])\)\
\)\)\)\)\), "\"\<c:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (cont)"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<cont of sum\>"], 
        using \[Rule] {Definition["\<cont\>"], Theory["\<auxiliary\>"]}\), 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(4.1  .1\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-1-1.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Show[TransMeta[%]]\)], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ 4.1  .1  a\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-1-1a.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<cont of product\>"], 
        using \[Rule] {Definition["\<cont\>"], Theory["\<auxiliary\>"]}\), 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(4.1  .2\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-1-2.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Show[TransMeta[%]]\)], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(4.1  .2  a\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-1-2a.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2. Definition with conditions", "Subsection"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<cont\>\"", ",", \(any[f]\), ",", "\n", "\t", GridBox[{
            {\(cont[
                  f]\  : \[NegativeMediumSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+x\(\(\[ForAll] \+\[Epsilon]\)\+\(\
\[Epsilon] > 0\)\(\(\[Exists] \+\[Delta]\)\+\(0 < \[Delta]\)\(\(\(\ \)\(\
\[ForAll]\)\)\+y\) \((\[LeftBracketingBar]y - 
                                    x\[RightBracketingBar] < \[Delta])\)\
\[DoubleLongRightArrow]\((\[LeftBracketingBar]f[y] - 
                                    f[x]\[RightBracketingBar] < \[Epsilon])\)\
\)\)\)\)\), "\"\<c:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (cont)"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<cont of sum\>"], 
        using \[Rule] {Definition["\<cont\>"], Theory["\<auxiliary\>"]}\), 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(4.2  .1\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-2-1.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Show[TransMeta[%]]\)], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(4.2  .1  a\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-2-1a.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<cont of product\>"], 
        using \[Rule] {Definition["\<cont\>"], Theory["\<auxiliary\>"]}\), 
        "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(4.2  .2\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-2-2.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Show[TransMeta[%]]\)], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(4.2  .2  a\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p4-2-2a.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Uniform Continuity", "Section"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<unif-cont\>\"", ",", \(any[f]\), ",", "\n", "\t", GridBox[{
            {\(ucont[
                  f]\  : \[NegativeMediumSpace]\[NegativeThickSpace]\(\(\
\[DoubleLongLeftRightArrow]\)\((\(\[ForAll] \+\[Epsilon]\)\+\(\[Epsilon] > \
0\)\(\(\[Exists] \+\[Delta]\)\+\(0 < \[Delta]\)\ \(\(\[ForAll] \+\(x, y\)\)\+\
\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\((\
\[LeftBracketingBar]f[y] - 
                                  f[x]\[RightBracketingBar] < \[Epsilon])\)\)\
\))\)\)\), "\"\<u:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (unif-cont)"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<unif-cont of sum\>"], 
        using \[Rule] {Definition["\<unif-cont\>"], 
            Theory["\<auxiliary\>"]}\), "]"}], ";"}]], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ 5.1\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p5-1.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[BoxData[
    \(Show[TransMeta[%]]\)], "Input"],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ \(5.1  a\)\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p5-1a.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell["\<\
The following proof fails because the only possible meta-solution would use a \
Skolem constant before it is created.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], 
        "[", \(Proposition["\<unif-cont of product\>"], 
        using \[Rule] {Definition["\<unif-cont\>"], 
            Theory["\<auxiliary\>"]}\), "]"}], ";"}]], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"The Skolem constant \"\>", "\[InvisibleSpace]", 
        StyleBox[\(x\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], 
        "\[InvisibleSpace]", "\<\" occurs in the expression of the \
meta-solution for \"\>", "\[InvisibleSpace]", \(\[Epsilon]\_1\%\("*"\)\), 
        "\[InvisibleSpace]", "\<\", thus\"\>"}],
      SequenceForm[ "The Skolem constant ", 
        \[Bullet]fix[ x, 0], 
        " occurs in the expression of the meta-solution for ", 
        \[Bullet]meta[ \[Epsilon], 1], ", thus"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"   the solution \"\>", 
        "\[InvisibleSpace]", \(\[Epsilon]\_1\%\("*"\)\), 
        "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
        FractionBox[
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          RowBox[{"1", "+", 
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{\(f\_1\), "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "\[RightBracketingBar]"}], "+", 
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{\(f\_2\), "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "\[RightBracketingBar]"}]}]], 
        "\[InvisibleSpace]", "\<\" is not admissible.\"\>"}],
      SequenceForm[ "   the solution ", 
        \[Bullet]meta[ \[Epsilon], 1], " = ", 
        \[Trademark]Divide[ 
          \[Bullet]fix[ \[Epsilon], 0], 
          \[Trademark]Plus[ 1, 
            \[Trademark]BracketingBar[ 
              \[Trademark]Subscript[ f, 1][ 
                \[Bullet]fix[ x, 0]]], 
            \[Trademark]BracketingBar[ 
              \[Trademark]Subscript[ f, 2][ 
                \[Bullet]fix[ x, 0]]]]], " is not admissible."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Failed meta-unification of \"\>", "\[InvisibleSpace]", 
        RowBox[{\(\[LeftBracketingBar]f\_1[y\_1\%\("*"\)] - 
                  f\_1[x\_1\%\("*"\)]\[RightBracketingBar] < \
\[Epsilon]\_1\%\("*"\) \[And] \[LeftBracketingBar]f\_2[y\_2\%\("*"\)] - 
                  f\_2[x\_2\%\("*"\)]\[RightBracketingBar] < \
\[Epsilon]\_2\%\("*"\)\), "\[Implies]", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{
                RowBox[{
                  RowBox[{\(f\_1\), "[", 
                    StyleBox[\(y\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "*", 
                  RowBox[{\(f\_2\), "[", 
                    StyleBox[\(y\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}]}], "-", 
                RowBox[{
                  RowBox[{\(f\_1\), "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "*", 
                  RowBox[{\(f\_2\), "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}]}]}], "\[RightBracketingBar]"}],
             "<", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "\[InvisibleSpace]", "\<\" against \"\>",
         "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "-", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              FractionBox[
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                RowBox[{"1", "+", 
                  RowBox[{"\[LeftBracketingBar]", 
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[RightBracketingBar]"}], "+", 
                  RowBox[{"\[LeftBracketingBar]", 
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[RightBracketingBar]"}]}]]}], 
            "\[And]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "-", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              FractionBox[
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                RowBox[{"1", "+", 
                  RowBox[{"\[LeftBracketingBar]", 
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[RightBracketingBar]"}], "+", 
                  RowBox[{"\[LeftBracketingBar]", 
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[RightBracketingBar]"}]}]]}]}], 
          "\[Implies]", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "-", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], "\[RightBracketingBar]"}], "<", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "\[InvisibleSpace]", "\<\".\"\>"}],
      SequenceForm[ "Failed meta-unification of ", 
        \[Trademark]Implies[ 
          \[Trademark]And[ 
            \[Trademark]Less[ 
              \[Trademark]BracketingBar[ 
                \[Trademark]Minus[ 
                  \[Trademark]Subscript[ f, 1][ 
                    \[Bullet]meta[ y, 1]], 
                  \[Trademark]Subscript[ f, 1][ 
                    \[Bullet]meta[ x, 1]]]], 
              \[Bullet]meta[ \[Epsilon], 1]], 
            \[Trademark]Less[ 
              \[Trademark]BracketingBar[ 
                \[Trademark]Minus[ 
                  \[Trademark]Subscript[ f, 2][ 
                    \[Bullet]meta[ y, 2]], 
                  \[Trademark]Subscript[ f, 2][ 
                    \[Bullet]meta[ x, 2]]]], 
              \[Bullet]meta[ \[Epsilon], 2]]], 
          \[Trademark]Less[ 
            \[Trademark]BracketingBar[ 
              \[Trademark]Minus[ 
                \[Trademark]Times[ 
                  \[Trademark]Subscript[ f, 1][ 
                    \[Bullet]fix[ y, 0]], 
                  \[Trademark]Subscript[ f, 2][ 
                    \[Bullet]fix[ y, 0]]], 
                \[Trademark]Times[ 
                  \[Trademark]Subscript[ f, 1][ 
                    \[Bullet]fix[ x, 0]], 
                  \[Trademark]Subscript[ f, 2][ 
                    \[Bullet]fix[ x, 0]]]]], 
            \[Bullet]fix[ \[Epsilon], 0]]], " against ", 
        \[Trademark]Implies[ 
          \[Trademark]And[ 
            \[Trademark]Less[ 
              \[Trademark]BracketingBar[ 
                \[Trademark]Minus[ 
                  \[Bullet]var[ x], 
                  \[Bullet]var[ a]]], 
              \[Trademark]Divide[ 
                \[Bullet]var[ \[Epsilon]], 
                \[Trademark]Plus[ 1, 
                  \[Trademark]BracketingBar[ 
                    \[Bullet]var[ a]], 
                  \[Trademark]BracketingBar[ 
                    \[Bullet]var[ b]]]]], 
            \[Trademark]Less[ 
              \[Trademark]BracketingBar[ 
                \[Trademark]Minus[ 
                  \[Bullet]var[ y], 
                  \[Bullet]var[ b]]], 
              \[Trademark]Divide[ 
                \[Bullet]var[ \[Epsilon]], 
                \[Trademark]Plus[ 1, 
                  \[Trademark]BracketingBar[ 
                    \[Bullet]var[ a]], 
                  \[Trademark]BracketingBar[ 
                    \[Bullet]var[ b]]]]]], 
          \[Trademark]Less[ 
            \[Trademark]BracketingBar[ 
              \[Trademark]Minus[ 
                \[Trademark]Times[ 
                  \[Bullet]var[ x], 
                  \[Bullet]var[ y]], 
                \[Trademark]Times[ 
                  \[Bullet]var[ a], 
                  \[Bullet]var[ b]]]], 
            \[Bullet]var[ \[Epsilon]]]], "."],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    ButtonBox[\(\(\ \)\(\(\[Rule]\)\(\ \)\(Proof\ 5.2\)\)\),
      ButtonData:>{
        FrontEnd`FileName[ {"Proofs"}, "p5-2.nb", CharacterEncoding -> 
          "WindowsANSI"], None},
      ButtonStyle->"Hyperlink"]], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["Generating conjectures", "Subsubsection"],

Cell[BoxData[
    \(The\ function\ operators\ are\ not\ \(\(expanded\)\(.\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], 
        "[", \(Proposition["\<unif-cont of product\>"], 
        using \[Rule] {Definition["\<unif-cont\>"]}\), "]"}], ";"}]], "Input",\

  CellTags->"Lemma (Conjecture\[Dash]4)"],

Cell[BoxData[
    \("The prover generated Lemma[\"Conjecture\[Dash]4\"]"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lemma["\<Conjecture\[Dash]4\>"]\)], "Input"],

Cell[BoxData[
    RowBox[{"\[Bullet]lma", "[", 
      RowBox[{"\<\"Conjecture\[Dash]4\"\>", ",", \(\[Bullet]range[]\), ",", 
        "True", ",", 
        RowBox[{"\[Bullet]flist", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\<\"Conjecture\[Dash]4\"\>", ",", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]0",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Epsilon]1",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["\[Epsilon]2",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]], 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x0",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], ",", 
                        StyleBox["y0",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["x2",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["y1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["y2",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              RowBox[{"\[LeftBracketingBar]", 
                                RowBox[{
                                  RowBox[{\(f\_1\), "[", 
                                    StyleBox["y1",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}], "-", 
                                  RowBox[{\(f\_1\), "[", 
                                    StyleBox["x1",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}]}], 
                                "\[RightBracketingBar]"}], "<", 
                              StyleBox["\[Epsilon]1",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "\[And]", 
                            RowBox[{
                              RowBox[{"\[LeftBracketingBar]", 
                                RowBox[{
                                  RowBox[{\(f\_2\), "[", 
                                    StyleBox["y2",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}], "-", 
                                  RowBox[{\(f\_2\), "[", 
                                    StyleBox["x2",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}]}], 
                                "\[RightBracketingBar]"}], "<", 
                              StyleBox["\[Epsilon]2",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], "\[Implies]", 
                          RowBox[{
                            RowBox[{"\[LeftBracketingBar]", 
                              RowBox[{
                                RowBox[{\((f\_1\[CircleDot]f\_2)\), "[", 
                                  StyleBox["y0",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "]"}], "-", 
                                RowBox[{\((f\_1\[CircleDot]f\_2)\), "[", 
                                  StyleBox["x0",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "]"}]}], 
                              "\[RightBracketingBar]"}], "<", 
                            StyleBox["\[Epsilon]0",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}]}]}]}]}], "]"}], 
          "]"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The previous conjecture is not valid. In fact, the product of uniformly \
continuous functions is not uniformly continuous (take e.g. ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1[x] = \(f\_2[x] = x\)\)]],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Prove",
          FontWeight->"Bold"], "[", \(Proposition["\<unif-cont of sum\>"], 
        using \[Rule] {Definition["\<unif-cont\>"]}\), "]"}], ";"}]], "Input",\

  CellTags->"Lemma (Conjecture\[Dash]5)"],

Cell[BoxData[
    \("The prover generated Lemma[\"Conjecture\[Dash]5\"]"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lemma["\<Conjecture\[Dash]5\>"]\)], "Input"],

Cell[BoxData[
    RowBox[{"\[Bullet]lma", "[", 
      RowBox[{"\<\"Conjecture\[Dash]5\"\>", ",", \(\[Bullet]range[]\), ",", 
        "True", ",", 
        RowBox[{"\[Bullet]flist", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\<\"Conjecture\[Dash]5\"\>", ",", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]0",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Epsilon]1",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["\[Epsilon]2",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]], 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x0",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], ",", 
                        StyleBox["y0",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["x2",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["y1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["y2",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{
                              RowBox[{"\[LeftBracketingBar]", 
                                RowBox[{
                                  RowBox[{\(f\_1\), "[", 
                                    StyleBox["y1",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}], "-", 
                                  RowBox[{\(f\_1\), "[", 
                                    StyleBox["x1",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}]}], 
                                "\[RightBracketingBar]"}], "<", 
                              StyleBox["\[Epsilon]1",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "\[And]", 
                            RowBox[{
                              RowBox[{"\[LeftBracketingBar]", 
                                RowBox[{
                                  RowBox[{\(f\_2\), "[", 
                                    StyleBox["y2",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}], "-", 
                                  RowBox[{\(f\_2\), "[", 
                                    StyleBox["x2",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}]}], 
                                "\[RightBracketingBar]"}], "<", 
                              StyleBox["\[Epsilon]2",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], "\[Implies]", 
                          RowBox[{
                            RowBox[{"\[LeftBracketingBar]", 
                              RowBox[{
                                RowBox[{\((f\_1\[CirclePlus]f\_2)\), "[", 
                                  StyleBox["y0",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "]"}], "-", 
                                RowBox[{\((f\_1\[CirclePlus]f\_2)\), "[", 
                                  StyleBox["x0",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "]"}]}], 
                              "\[RightBracketingBar]"}], "<", 
                            StyleBox["\[Epsilon]0",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]}], ")"}]}]}]}]}]}], "]"}], 
          "]"}]}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 670}},
AutoGeneratedPackage->Automatic,
WindowSize->{1016, 630},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Definition (sum of functions)"->{
    Cell[2022, 67, 453, 12, 68, "Input",
      InitializationCell->True,
      CellTags->"Definition (sum of functions)"]},
  "Definition (product of functions)"->{
    Cell[2478, 81, 458, 12, 68, "Input",
      InitializationCell->True,
      CellTags->"Definition (product of functions)"]},
  "Proposition (distance of sum)"->{
    Cell[2939, 95, 860, 19, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (distance of sum)"]},
  "Proposition (distance of product)"->{
    Cell[3802, 116, 981, 20, 94, "Input",
      InitializationCell->True,
      CellTags->"Proposition (distance of product)"]},
  "Proposition (max)"->{
    Cell[4786, 138, 496, 12, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (max)"]},
  "Proposition (min)"->{
    Cell[5285, 152, 435, 11, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (min)"]},
  "Proposition (eps/2)"->{
    Cell[5723, 165, 463, 12, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (eps/2)"]},
  "Proposition (eps/ab)"->{
    Cell[6189, 179, 560, 14, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (eps/ab)"]},
  "Theory (auxiliary)"->{
    Cell[6752, 195, 983, 25, 238, "Input",
      InitializationCell->True,
      CellTags->"Theory (auxiliary)"]},
  "Proposition (conv of sum)"->{
    Cell[7805, 227, 486, 11, 114, "Input",
      InitializationCell->True,
      CellTags->"Proposition (conv of sum)"],
    Cell[8294, 240, 470, 11, 100, "Input",
      InitializationCell->True,
      CellTags->"Proposition (conv of sum)"]},
  "Proposition (conv of product)"->{
    Cell[8767, 253, 493, 11, 114, "Input",
      InitializationCell->True,
      CellTags->"Proposition (conv of product)"]},
  "Proposition (lim of sum)"->{
    Cell[9263, 266, 500, 11, 114, "Input",
      InitializationCell->True,
      CellTags->"Proposition (lim of sum)"]},
  "Proposition (lim of product)"->{
    Cell[9766, 279, 505, 11, 114, "Input",
      InitializationCell->True,
      CellTags->"Proposition (lim of product)"]},
  "Proposition (cont of sum)"->{
    Cell[10274, 292, 429, 10, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (cont of sum)"]},
  "Proposition (cont of product)"->{
    Cell[10706, 304, 436, 10, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (cont of product)"]},
  "Proposition (unif-cont of sum)"->{
    Cell[11145, 316, 442, 10, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (unif-cont of sum)"]},
  "Proposition (unif-cont of product)"->{
    Cell[11590, 328, 449, 10, 68, "Input",
      InitializationCell->True,
      CellTags->"Proposition (unif-cont of product)"]},
  "Definition (conv)"->{
    Cell[12356, 355, 703, 14, 78, "Input",
      CellTags->"Definition (conv)"]},
  "Lemma (Conjecture\[Dash]1)"->{
    Cell[13084, 373, 303, 7, 68, "Input",
      CellTags->"Lemma (Conjecture\[Dash]1)"]},
  "Lemma (Conjecture\[Dash]10)"->{
    Cell[13390, 382, 128, 2, 35, "Print",
      CellTags->"Lemma (Conjecture\[Dash]10)"]},
  "Lemma (Conjecture\[Dash]2)"->{
    Cell[20247, 528, 352, 8, 94, "Input",
      CellTags->"Lemma (Conjecture\[Dash]2)"]},
  "Lemma (Conjecture\[Dash]3)"->{
    Cell[23965, 622, 385, 9, 94, "Input",
      CellTags->"Lemma (Conjecture\[Dash]3)"]},
  "Definition (cont)"->{
    Cell[29498, 789, 743, 15, 80, "Input",
      CellTags->"Definition (cont)"],
    Cell[32052, 865, 791, 16, 91, "Input",
      CellTags->"Definition (cont)"]},
  "Definition (unif-cont)"->{
    Cell[34657, 943, 735, 16, 130, "Input",
      CellTags->"Definition (unif-cont)"]},
  "Lemma (Conjecture\[Dash]4)"->{
    Cell[47189, 1268, 279, 8, 68, "Input",
      CellTags->"Lemma (Conjecture\[Dash]4)"]},
  "Lemma (Conjecture\[Dash]5)"->{
    Cell[53549, 1412, 266, 7, 42, "Input",
      CellTags->"Lemma (Conjecture\[Dash]5)"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Definition (sum of functions)", 60331, 1565},
  {"Definition (product of functions)", 60496, 1569},
  {"Proposition (distance of sum)", 60661, 1573},
  {"Proposition (distance of product)", 60826, 1577},
  {"Proposition (max)", 60980, 1581},
  {"Proposition (min)", 61118, 1585},
  {"Proposition (eps/2)", 61258, 1589},
  {"Proposition (eps/ab)", 61401, 1593},
  {"Theory (auxiliary)", 61543, 1597},
  {"Proposition (conv of sum)", 61691, 1601},
  {"Proposition (conv of product)", 61971, 1608},
  {"Proposition (lim of sum)", 62129, 1612},
  {"Proposition (lim of product)", 62286, 1616},
  {"Proposition (cont of sum)", 62444, 1620},
  {"Proposition (cont of product)", 62603, 1624},
  {"Proposition (unif-cont of sum)", 62767, 1628},
  {"Proposition (unif-cont of product)", 62936, 1632},
  {"Definition (conv)", 63092, 1636},
  {"Lemma (Conjecture\[Dash]1)", 63208, 1639},
  {"Lemma (Conjecture\[Dash]10)", 63333, 1642},
  {"Lemma (Conjecture\[Dash]2)", 63458, 1645},
  {"Lemma (Conjecture\[Dash]3)", 63582, 1648},
  {"Definition (cont)", 63697, 1651},
  {"Definition (unif-cont)", 63890, 1656},
  {"Lemma (Conjecture\[Dash]4)", 64012, 1659},
  {"Lemma (Conjecture\[Dash]5)", 64137, 1662}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 38, 0, 141, "Title"],
Cell[1817, 55, 34, 0, 76, "Subtitle"],
Cell[1854, 57, 32, 0, 44, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1911, 61, 39, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[1975, 65, 44, 0, 40, "Subsubsection"],
Cell[2022, 67, 453, 12, 68, "Input",
  InitializationCell->True,
  CellTags->"Definition (sum of functions)"],
Cell[2478, 81, 458, 12, 68, "Input",
  InitializationCell->True,
  CellTags->"Definition (product of functions)"],
Cell[2939, 95, 860, 19, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (distance of sum)"],
Cell[3802, 116, 981, 20, 94, "Input",
  InitializationCell->True,
  CellTags->"Proposition (distance of product)"],
Cell[4786, 138, 496, 12, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (max)"],
Cell[5285, 152, 435, 11, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (min)"],
Cell[5723, 165, 463, 12, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (eps/2)"],
Cell[6189, 179, 560, 14, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (eps/ab)"],
Cell[6752, 195, 983, 25, 238, "Input",
  InitializationCell->True,
  CellTags->"Theory (auxiliary)"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7772, 225, 30, 0, 40, "Subsubsection"],
Cell[7805, 227, 486, 11, 114, "Input",
  InitializationCell->True,
  CellTags->"Proposition (conv of sum)"],
Cell[8294, 240, 470, 11, 100, "Input",
  InitializationCell->True,
  CellTags->"Proposition (conv of sum)"],
Cell[8767, 253, 493, 11, 114, "Input",
  InitializationCell->True,
  CellTags->"Proposition (conv of product)"],
Cell[9263, 266, 500, 11, 114, "Input",
  InitializationCell->True,
  CellTags->"Proposition (lim of sum)"],
Cell[9766, 279, 505, 11, 114, "Input",
  InitializationCell->True,
  CellTags->"Proposition (lim of product)"],
Cell[10274, 292, 429, 10, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (cont of sum)"],
Cell[10706, 304, 436, 10, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (cont of product)"],
Cell[11145, 316, 442, 10, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (unif-cont of sum)"],
Cell[11590, 328, 449, 10, 68, "Input",
  InitializationCell->True,
  CellTags->"Proposition (unif-cont of product)"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12088, 344, 33, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[12146, 348, 52, 0, 56, "Subsection"],
Cell[12201, 350, 152, 3, 73, "Text"],
Cell[12356, 355, 703, 14, 78, "Input",
  CellTags->"Definition (conv)"],

Cell[CellGroupData[{
Cell[13084, 373, 303, 7, 68, "Input",
  CellTags->"Lemma (Conjecture\[Dash]1)"],
Cell[13390, 382, 128, 2, 35, "Print",
  CellTags->"Lemma (Conjecture\[Dash]10)"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13555, 389, 64, 1, 42, "Input"],
Cell[13622, 392, 6312, 123, 112, "Output"]
}, Open  ]],
Cell[19949, 518, 273, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[20247, 528, 352, 8, 94, "Input",
  CellTags->"Lemma (Conjecture\[Dash]2)"],
Cell[20602, 538, 85, 1, 35, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20724, 544, 64, 1, 42, "Input"],
Cell[20791, 547, 2861, 62, 84, "Output"]
}, Open  ]],
Cell[23667, 612, 273, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[23965, 622, 385, 9, 94, "Input",
  CellTags->"Lemma (Conjecture\[Dash]3)"],
Cell[24353, 633, 85, 1, 35, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24475, 639, 64, 1, 42, "Input"],
Cell[24542, 642, 1177, 27, 88, "Output"]
}, Open  ]],
Cell[25734, 672, 273, 6, 45, "Text"],
Cell[26010, 680, 661, 16, 120, "Input"],
Cell[26674, 698, 273, 6, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26984, 709, 50, 0, 56, "Subsection"],
Cell[27037, 711, 257, 5, 73, "Text"],
Cell[27297, 718, 246, 6, 68, "Input"],
Cell[27546, 726, 273, 6, 45, "Text"],
Cell[27822, 734, 326, 5, 99, "Text"],
Cell[28151, 741, 51, 1, 42, "Input"],
Cell[28205, 744, 277, 6, 45, "Text"],
Cell[28485, 752, 250, 6, 68, "Input"],
Cell[28738, 760, 273, 6, 45, "Text"],
Cell[29014, 768, 51, 1, 42, "Input"],
Cell[29068, 771, 277, 6, 45, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29394, 783, 32, 0, 109, "Section"],

Cell[CellGroupData[{
Cell[29451, 787, 44, 0, 56, "Subsection"],
Cell[29498, 789, 743, 15, 80, "Input",
  CellTags->"Definition (cont)"],
Cell[30244, 806, 246, 6, 68, "Input"],
Cell[30493, 814, 273, 6, 45, "Text"],
Cell[30769, 822, 51, 1, 42, "Input"],
Cell[30823, 825, 273, 6, 45, "Text"],
Cell[31099, 833, 250, 6, 68, "Input"],
Cell[31352, 841, 273, 6, 45, "Text"],
Cell[31628, 849, 51, 1, 42, "Input"],
Cell[31682, 852, 277, 6, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31996, 863, 53, 0, 56, "Subsection"],
Cell[32052, 865, 791, 16, 91, "Input",
  CellTags->"Definition (cont)"],
Cell[32846, 883, 246, 6, 68, "Input"],
Cell[33095, 891, 273, 6, 45, "Text"],
Cell[33371, 899, 51, 1, 42, "Input"],
Cell[33425, 902, 277, 6, 45, "Text"],
Cell[33705, 910, 250, 6, 68, "Input"],
Cell[33958, 918, 273, 6, 45, "Text"],
Cell[34234, 926, 51, 1, 42, "Input"],
Cell[34288, 929, 277, 6, 45, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34614, 941, 40, 0, 109, "Section"],
Cell[34657, 943, 735, 16, 130, "Input",
  CellTags->"Definition (unif-cont)"],
Cell[35395, 961, 260, 6, 68, "Input"],
Cell[35658, 969, 263, 6, 45, "Text"],
Cell[35924, 977, 51, 1, 42, "Input"],
Cell[35978, 980, 271, 6, 45, "Text"],
Cell[36252, 988, 141, 3, 47, "Text"],

Cell[CellGroupData[{
Cell[36418, 995, 273, 7, 68, "Input"],
Cell[36694, 1004, 639, 14, 60, "Print"],
Cell[37336, 1020, 1494, 35, 52, "Print"],
Cell[38833, 1057, 7888, 191, 104, "Print"]
}, Open  ]],
Cell[46736, 1251, 263, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[47024, 1261, 47, 0, 40, "Subsubsection"],
Cell[47074, 1263, 90, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[47189, 1268, 279, 8, 68, "Input",
  CellTags->"Lemma (Conjecture\[Dash]4)"],
Cell[47471, 1278, 85, 1, 35, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47593, 1284, 64, 1, 42, "Input"],
Cell[47660, 1287, 5603, 112, 114, "Output"]
}, Open  ]],
Cell[53278, 1402, 246, 6, 73, "Text"],

Cell[CellGroupData[{
Cell[53549, 1412, 266, 7, 42, "Input",
  CellTags->"Lemma (Conjecture\[Dash]5)"],
Cell[53818, 1421, 85, 1, 35, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53940, 1427, 64, 1, 42, "Input"],
Cell[54007, 1430, 5605, 112, 114, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

